@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: JABBER.pm,v 1.3 2004/11/14 19:30:50 byrnereese Exp $
+# $Id: JABBER.pm 341 2009-09-30 18:34:58Z kutterma $
 #
 # ======================================================================
 
@@ -12,13 +12,12 @@ package SOAP::Transport::JABBER;
 
 use strict;
 use vars qw($VERSION);
-#$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name: release-0_65-beta4 $ =~ /-(\d+)_([\d_]+)/);
-$VERSION = $SOAP::Lite::VERSION;
+
+use SOAP::Lite; $VERSION = $SOAP::Lite::VERSION;
 
 use Net::Jabber 1.0021 qw(Client); 
 use URI::Escape; 
 use URI;
-use SOAP::Lite;
 
 my $NAMESPACE = "http://namespaces.soaplite.com/transport/jabber";
 
